==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-server/src/main/java/org/apache/hadoop/hbase/CoordinatedStateManager.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase;

import org.apache.hadoop.hbase.classification.InterfaceAudience;

/**
 * Implementations of this interface will keep and return to clients
 * implementations of classes providing API to execute
 * coordinated operations. This interface is client-side, so it does NOT
 * include methods to retrieve the particular interface implementations.
 *
 * For each coarse-grained area of operations there will be a separate
 * interface with implementation, providing API for relevant operations
 * requiring coordination.
 *
 * Property hbase.coordinated.state.manager.class in hbase-site.xml controls
 * which provider to use.
 */
@InterfaceAudience.Private
public interface CoordinatedStateManager {

  /**
   * Initialize coordinated state management service.
   * @param server server instance to run within.
   */
  void initialize(Server server);

  /**
   * Starts service.
   */
  void start();

  /**
   * Stops service.
   */
  void stop();

  /**
   * @return instance of Server coordinated state manager runs within
   */
  Server getServer();

  /**
   * Returns implementation of TableStateManager.
   * @throws InterruptedException if operation is interrupted
   * @throws CoordinatedStateException if error happens in underlying coordination mechanism
   */
  TableStateManager getTableStateManager() throws InterruptedException,
    CoordinatedStateException;
}

==> hbase-2.3.7-src.tar.gz: hbase-2.3.7/hbase-server/src/main/java/org/apache/hadoop/hbase/CoordinatedStateManager.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase;

import org.apache.hadoop.hbase.coordination.SplitLogManagerCoordination;
import org.apache.hadoop.hbase.coordination.SplitLogWorkerCoordination;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Implementations of this interface will keep and return to clients
 * implementations of classes providing API to execute
 * coordinated operations. This interface is client-side, so it does NOT
 * include methods to retrieve the particular interface implementations.
 *
 * For each coarse-grained area of operations there will be a separate
 * interface with implementation, providing API for relevant operations
 * requiring coordination.
 */
@InterfaceAudience.Private
public interface CoordinatedStateManager {
  /**
   * Method to retrieve coordination for split log worker
   */
  SplitLogWorkerCoordination getSplitLogWorkerCoordination();

  /**
   * Method to retrieve coordination for split log manager
   */
  SplitLogManagerCoordination getSplitLogManagerCoordination();
}
